package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,``P`!````XA0``#0```#HD````````#0`(``(
M`"@`&``7``8````T````-````#0``````0````$```0````$`````P```#0!
M```T`0``-`$``!<````7````!`````$````!````````````````````7(<`
M`%R'```%`````!````$```#DC0``Y)T``.2=``!``@``D!(```8`````$```
M`@```/B-``#XG0``^)T``-````#0````!@````0```!0Y71D+'H``"QZ```L
M>@``W````-P````$````!````%'E=&0```````````````````````````8`
M```0````4N5T9.2-``#DG0``Y)T``!P"```<`@``!`````$````O;&EB+VQD
M+6UU<VPM:3,X-BYS;RXQ```1````3`````0````'`````($``)M$!$E(CA`A
MBH0$R`````!,````4````%0```!5````6@```%L```!<`````````%X`````
M`````````%\```!@````80``````````````:G^:?.K3[P[.WD<M;\7?'R[%
MF[:XC?$.U&34?"'_Y`[9<5@<^J%L8,+E/RRR`8MOXD?&`;OCDGQ5PSS29Z_,
M9H@'<--#1=7L,V+;[7^IG)OAIP(*H^#[20`````````````````````,````
M```````````2````R0$`````````````$@```!0``````````````!$```#O
M`0`````````````1````:P$`````````````$@```!L``````````````!(`
M``"H`0`````````````2````(P``````````````$@```"H`````````````
M`!(```#\`0`````````````2````M`$`````````````$@```$(#````````
M`````"$````S```````````````2````.0``````````````$@```$``````
M`````````!(````(`P`````````````2````^0(`````````````$@```($"
M`````````````!(```!'```````````````2````(@(`````````````$@``
M`$X``````````````!(```"V`@`````````````2````50``````````````
M$@```%T``````````````"````!Q```````````````2````GP(`````````
M````$@```'D``````````````!(```!_```````````````2````B```````
M````````(````/("`````````````!(```"D```````````````2````J0``
M````````````$@````T"`````````````!$```"]`@`````````````2````
M3P(`````````````$@```!@#`````````````!(```"P```````````````@
M````00(`````````````$@```(\#`````````````!(```#(`@``````````
M```1````00,`````````````$0```',"`````````````!(````N`P``````
M```````2````0P,`````````````$0```,X``````````````!(````F`P``
M```````````2````>0$`````````````$@```-<``````````````"(```#F
M```````````````2````Z@(`````````````$@```%\"`````````````!(`
M``#K```````````````2````\0``````````````(````*H"````````````
M`!(````+`0`````````````2````F0$`````````````$@```!`!````````
M`````"`````L`0`````````````2````CP(`````````````$@```(@!````
M`````````!(````R`0`````````````2````0P$`````````````$@```!T"
M`````````````!(```!Z```````````````2````+@(`````````````$@``
M`&@"`````````````!(````?`P`````````````2````20$`````````````
M$@```!`#`````````````!(```!=`0`````````````2````&`(`````````
M````$@```-<!`````````````!(```!+`P`````````````2````0`,`````
M````````(0```&0!`````````````!(````[`P``"!,``-H!```2``H`Z0$`
M```[```!````$@`+`-$#``"Q+0``KPD``!(`"@!'!```7CH``%X````2``H`
MK@,``+$H```%````$@`*`.`#```L#P```0```!(`!P#T`P``8#<``/X"```2
M``H`.@0``+8H``"P`0``$@`*`&,#```DH````````!``%0"_`P``""T``*D`
M```2``H`W@,``#XG```[````$@`*`.8#``".+```2P```!(`"@`4!```9BH`
M`!D````2``H`;P,``'2P````````$``5`'0#``#]%```,@```!(`"@`A!```
M?RH``+$````2``H`"@0``""@```$````$0`4`%P#```DH````````!``%`!H
M`P``XA0````````0``H`?0,``-DL```O````$@`*`)@#``#,)P``Y0```!(`
M"@`M!```,"L``%X!```2``H``&QI8G!E<FPN<V\`;W!E;F1I<@!S=&1E<G(`
M<F5A;&QO8P!A8V-E<W,`<VYP<FEN=&8`;'-E96L`9V5T<&ED`'-T<F-M<`!M
M96US970`=6YL:6YK`&UE;6UO=F4`7TIV7U)E9VES=&5R0VQA<W-E<P!S=')N
M8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I<W1E<E1-0VQO;F5486)L
M90!O<&5N`'-T<G-T<@!?7V1E<F5G:7-T97)?9G)A;65?:6YF;U]B87-E<P!R
M96%D;&EN:P!?7V-X85]F:6YA;&EZ90!E>&ET`&-L;W-E`%])5$U?<F5G:7-T
M97)434-L;VYE5&%B;&4`<F5A9`!?7W)E9VES=&5R7V9R86UE7VEN9F]?8F%S
M97,`<FUD:7(`7U]E<G)N;U]L;V-A=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P
M96-I9FEC`&UE;6-P>0!G971U:60`4&5R;%]S>7-?=&5R;0!097)L7W-Y<U]I
M;FET,P!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T
M7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S
M=E\R<'9?9FQA9W,`7V9I;FD`4$Q?9&]?=6YD=6UP`%!E<FQ?;F5W6%-?9FQA
M9W,`4$Q?=&AR7VME>0!P97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O
M<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?
M<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E=&-H`&)O
M;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA;&QO8P!P
M97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F,N;75S;"UX.#8N<V\N,0!F
M<')I;G1F`'-T<F1U<`!P=&AR96%D7V%T9F]R:P!R96%D9&ER`'-P<FEN=&8`
M<W1R8VAR`'-T<G1O:P!S=')N8W!Y`%]?;&EB8U]S=&%R=%]M86EN`%]?7V5N
M=FER;VX`7U]S=&%C:U]C:&M?9F%I;`!?961A=&$`7U]B<W-?<W1A<G0`7V5N
M9`!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8W5R
M<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?;&EB
M<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A37TEN
M=&5R;F%L<U]005)?0D]/5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`'!A<E]D
M:7)N86UE`'!A<E]I;FET7V5N=@!P87)?9FEN9'!R;V<`<&%R7V-L96%N=7``
M+W5S<B]L:6(O<&5R;#4O8V]R95]P97)L+T-/4D4`````O)\```@```#(GP``
M"````-2?```(`````*````@````$H```"`````B@```(````#*````@````0
MH```"````!2@```(````(*````@```#`GP``!@,``,2?```&!```S)\```88
M``#0GP``!AT``-B?```&(0``W)\```8E``#@GP``!B@``.2?```&+```Z)\`
M``8P``#LGP``!C4``/"?```&.0``])\```8[``#XGP``!CP``/R?```&00``
MU)X```<!``#8G@``!P(``-R>```'!0``X)X```<&``#DG@``!P<``.B>```'
M"```[)X```<)``#PG@``!PH``/2>```'"P``^)X```<-``#\G@``!PX```"?
M```'#P``!)\```<0```(GP``!Q$```R?```'$@``$)\```<3```4GP``!Q0`
M`!B?```'%0``')\```<6```@GP``!Q<``"2?```'&0``*)\```<:```LGP``
M!QL``#"?```''```-)\```<>```XGP``!Q\``#R?```'(```0)\```<B``!$
MGP``!R,``$B?```')```3)\```<F``!0GP``!R<``%2?```'*@``6)\```<K
M``!<GP``!RT``&"?```'+@``9)\```<O``!HGP``!S$``&R?```',@``<)\`
M``<S``!TGP``!S0``'B?```'-@``?)\```<W``"`GP``!S@``(2?```'.@``
MB)\```<]``",GP``!SX``)"?```'/P``E)\```=```"8GP``!T(``)R?```'
M0P``H)\```=$``"DGP``!T4``*B?```'1@``K)\```='``"PGP``!T@``+2?
M```'20``N)\```=+``"#[`SH"0<``.B@*P``@\0,PP```/^S!````/^C"```
M``````#_HPP```!H`````.G@_____Z,0````:`@```#IT/____^C%````&@0
M````Z<#_____HQ@```!H&````.FP_____Z,<````:"````#IH/____^C(```
M`&@H````Z9#_____HR0```!H,````.F`_____Z,H````:#@```#I</____^C
M+````&A`````Z6#_____HS````!H2````.E0_____Z,T````:%````#I0/__
M__^C.````&A8````Z3#_____HSP```!H8````.D@_____Z-`````:&@```#I
M$/____^C1````&AP````Z0#_____HT@```!H>````.GP_O___Z-,````:(``
M``#IX/[___^C4````&B(````Z=#^____HU0```!HD````.G`_O___Z-8````
M:)@```#IL/[___^C7````&B@````Z:#^____HV````!HJ````.F0_O___Z-D
M````:+````#I@/[___^C:````&BX````Z7#^____HVP```!HP````.E@_O__
M_Z-P````:,@```#I4/[___^C=````&C0````Z4#^____HW@```!HV````.DP
M_O___Z-\````:.````#I(/[___^C@````&CH````Z1#^____HX0```!H\```
M`.D`_O___Z.(````:/@```#I\/W___^CC````&@``0``Z>#]____HY````!H
M"`$``.G0_?___Z.4````:!`!``#IP/W___^CF````&@8`0``Z;#]____HYP`
M``!H(`$``.F@_?___Z.@````:"@!``#ID/W___^CI````&@P`0``Z8#]____
MHZ@```!H.`$``.EP_?___Z.L````:$`!``#I8/W___^CL````&A(`0``Z5#]
M____H[0```!H4`$``.E`_?___Z.X````:%@!``#I,/W___^CO````&A@`0``
MZ2#]____H\````!H:`$``.D0_?___Z/$````:'`!``#I`/W___^CR````&AX
M`0``Z?#\____H\P```!H@`$``.G@_/___Z/0````:(@!``#IT/S___^CU```
M`&B0`0``Z<#\____H]@```!HF`$``.FP_/___Z/<````:*`!``#IH/S___^C
MX````&BH`0``Z9#\____H^0```!HL`$``.F`_/___Z/H````:+@!``#I</S_
M__^C[````&C``0``Z6#\____H_````!HR`$``.E0_/___Z,4`0``9I#_HR`!
M``!FD/^C*`$``&:0C4PD!(/D\/]Q_%6-00B)Y5=64U&)SN@,`@``@<.EBP``
M@^P,4(U!!%!1Z%G^__^+@S0!``"#Q`Q04/^S,`$``.C3_/__BX/\````@\00
MB[L0`0``@#@`=33HFOW__X7`B8.H$0``=0J#[`QJ`>@F_O__@^P,4.A]_O__
M6?\WZ/7^__^#Q!#&@%$%````@^P,_S?HX?[__X"(Z@(```):_S?HTO[__X"(
MZ@(```&+!H/$$(/`!3W___\_=A104(V#BYS___^S&`$``%#H^/O__X/L#,'@
M`E#H_/W__XM^!(F#G!$``(/$$,>#H!$```0```"Y`0```(L7B1"-D_F>__^)
M4`2+DU@!``")4`B-D_R>__^)4`R+%CG1?0J+-(^)=(@,0>OR@^P,QT20#```
M``"#P@-J`%"-@[&(__]24/^SJ!$``.A._/__@\0@A<")QG43@^P,_[.H$0``
MZ%?]__^#Q!")QH/L#/^SJ!$``.C4_/__C8/9G/__Z)$.``"#Q!"%P'4P@[ND
M$0```'41C8..G/__Z'8.``")@Z01``"+@Z01``"%P'0,@^P,4.BC)0``@\00
M@^P,_[.H$0``Z.3]___HG_K__X/$$(UE\(GP65M>7UV-8?S#,>V)X(/D\%!0
MZ`````"!!"0(B0``4.@`````4^@L````@</%B0``@^P0BT0D&&H`_[,``0``
M_[,,`0``C5`$4O\P_[/T````Z#'\__^+'"3#Z&H!```%D(D``(V(7`$``(V0
M7P$``"G*@_H&=A>+@`@!``"%P'0-58GE@^P44?_0@\00R<-5Z#@!``"!P5J)
M``")Y593C8%<`0``C9E<`0``O@(````IV,'X`IGW_H7`=!.+D20!``"%TG0)
M45%04__2@\00C67X6UY=PU6)Y5=64^AU____@<,.B0``@^P,@+MX`0```'5I
M@[L@`0```'01@^P,_[,X`0``Z!7]__^#Q!"-LR3___^-NRC___\I]\'_`D^+
M@WP!```YQW8,0(F#?`$``/\4ANOJZ"#___^#NQ0!````=!*-@Y#<__^#[`Q0
MZ,7\__^#Q!#&@W@!```!C67T6UY?7<-5Z`````!:@<*%B```B>534.C<_O__
M@<-UB```@[LH`0```'09C8.``0``4FH`4(V#D-S__U#HB/S__X/$$(V3+/__
M_X,Z`'03BX,$`0``A<!T"8/L#%+_T(/$$(M=_,GIQO[__XL$),.+#"3#55<Q
MTE93@>Q\`0``B40D"&6A%````(F$)&P!```QP(M$)`B-6!R+#).-1"0L#\F)
M#)!"@_H0=>Z-C"0L`0``BU`T,U`@@\`$,U`$,U#\T<*)4#PYR'7HBT0D"(L`
MB40D$(M$)`B+5"00BT`$P<H"B40D&(M$)`B+3"08BT`(P<D"B40D#(M$)`B+
M?"0,BVPD#(M`##'/(WPD$#-\)`R)1"04BT0D"(M<)!2+0!")1"0<BT0D+(MT
M)!R-M`:9>8):BT0D$,'`!0'PBW0D##-T)!0C="08,W0D%`'&BT0D,(V$`YEY
M@EJ)RS'3`<>)\"'SP<`%,<O!S@(!QXM$)#2-A`69>8):BVPD.`'#B?C!P`6-
MC"F9>8):BVPD/`'#B=`Q\"'XP<\",="-E"J9>8):BVPD0`'(B=G!P04!R(GQ
M,?DAV3'QC;0NF7F"6HML)$0!T8G"P<(%P<L"`=&)^C':(<+!R`(Q^HV\+YEY
M@EJ+;"1(`?*)SL'&!0'RB<:)V#'P(<@QV(V<*YEY@EJ+;"1,`?B)U\''!0'X
MB<^)\<'/`C'Y(=$Q\8VT+IEY@EJ+;"10`=F)P\'#!0'9B=.)^L'+`C':(<+!
MR`(Q^HV\+YEY@EJ+;"14`?*)SL'&!0'RB<:)V#'P(<@QV(V<*YEY@EJ+;"18
M`?B)U\''!0'XB<^)\<'/`C'Y(=$Q\8VT+IEY@EJ+;"1<`=F)P\'#!0'9B=.)
M^L'+`C':(<+!R`(Q^HV\+YEY@EJ+;"1@`?*)SL'&!0'RB<:)V#'P(<@QV(V<
M*YEY@EJ+;"1D`?B)U\''!0'XB<^)\<'/`C'Y(=$Q\8VT+IEY@EH!V8G#P<,%
M`=F)TXGZP<L",=HAPL'(`C'ZB<6)V`'RB<XQZ,'&!2'(P<D"`?*+="1H,=B-
MM#>9>8):B>\QSP'PB=8AU\'&!3'OP<H"`?"+="1LC9PSF7F"6HG.,=8!WXG#
M(<;!PP4QSL'(`@'?BUPD<(V<'9EY@EJ+;"1T`=Z)^\'#!8V,*9EY@EJ+;"1X
M`=Z)TS'#(?LQT\'/`HV4*IEY@EH!RXGQP<$%`<N)P3'Y(?'!S@(QP0'1B=K!
MP@4!T8M4)'R-A!"AZ]ENB?HQ\C':P<L"`<*)R,'`!0'"BX0D@````(V\!Z'K
MV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)(0```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)
MQL'&!0'QB=:+E"2(````P<X"C9P3H>O9;HGZ,?(QP@':B<O!R`+!PP4!VHG#
MBX0DC````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,))````#!SP*-M`ZA
MZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"24````P<X"C9P3H>O9;HGZ,?(QPL'(
M`@':B<O!PP4!VHG#BX0DF````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,
M))P```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"2@````P<X"C9P3
MH>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0DI````(V\!Z'KV6Z)\#'8,<@!
M^(G7P<<%`?B)SXN,)*@```#!SP*-M`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+
ME"2L````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!VHG#BX0DL````(V\
M!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,)+0```#!SP*-M`ZAZ]ENB=DQ^3'1
M`?&)QL'&!0'QB=:+E"2X````P<X"C9P3H>O9;HGZ,?(QPL'(`@':B<O!PP4!
MVHG#BX0DO````(V\!Z'KV6Z)\#'8,<@!^(G7P<<%`?B)SXN,),````#!SP*-
MM`ZAZ]ENB=DQ^3'1`?&)QL'&!0'QB=:+E"3$````P<X"C9P3H>O9;HGZ,?(Q
MPL'(`HG%BX0DR`````':B<O!PP4!VHV<!Z'KV6Z)\#'H,<@!V(G3P<D"P<,%
M`=B)ZPG+B=^)ZR'7(<O!R@()^XN\),P```"-M#[<O!N/B<\)UP'SB<;!Q@4!
M\XG^B<\AQB'7P<@""?>+M"30````C;0UW+P;CP'WB=[!Q@4!]XG6"<8AWL'+
M`HGUB=8AQ@GNBZPDU````(V,*=R\&X^)W8G#">L!SHGY(?O!P04!SHG9B<,A
MZPG+BXPDV````(V4"MR\&X^)Z0'3P<\"B?()^<'"!2'Q`=/!S@*)RHGI(?D)
MT8N4)-P```"-A!#<O!N/B?H)\@'!B=C!P`4!P8G0B?HAV"'RP<L""<*+A"3@
M````C80%W+P;CP'"B<C!P`4!PHGP"=@AR(G%B?`AV`GHBZPDY````(V\+]R\
M&X\!^(G7P<<%`?B)SXG9P<\""?DAT8G-B=DA^0GIBZPDZ````(VT+MR\&X\!
M\8G&P<8%`?&)UHGZP<X""?(APL'(`HG5B?HA\@GJBZPD[````(V<*]R\&X\!
MVHG+P<,%`=J)PXGP"=@AR(G%B?`AV`GHBZPD\````(V\+]R\&X\!^(G7P<<%
M`?B)SXG9P<\""?DAT8G-B=DA^0GIBZPD]````(VT+MR\&X\!\8G&P<8%`?&)
MUHGZP<X""?(APHG5B?HA\@GJBZPD^````(V<*]R\&X\!VHG+P<@"P<,%`=J)
MPXGP"=@AR(G%B?`AV`GHBZPD_````(V\+]R\&X\!^(G7P<<%`?B)SXG9P<\"
M"?DAT8G-B=DA^0GIBZPD``$``(VT+MR\&X\!\8G&P<8%`?&)UHGZP<X""?(A
MPL'(`HG5B?HA\@GJBZPD!`$``(V<*]R\&X^)Q8GP">@!VHG+(<C!PP4!VHG#
MB?`AZ`G8BYPD"`$``(V<']R\&X\!V(G3P<D"P<,%`=B)ZPG+B=^)ZR'7(<O!
MR@()^XN\)`P!``"-M#[<O!N/`?.)QL'&!0'SB<X)UHGWB<XAQR'6P<@""?Z+
MO"00`0``C;P]W+P;CP'^B=_!QP4!_HG7"<<AW\'+`HG]B=<AQPGOBZPD%`$`
M`(V,*=R\&X\!^8GWP<<%`?F)QPG?(?>)_8G'(=\)[XNL)!@!``"-E"K<O!N/
M`=>)RL'.`L'"!0'7BY0D'`$``(V4$-;!8LJ)V#'P,<C!R0(!T(GZP<(%`="+
ME"0@`0``C9P3UL%BRHGR,<HQ^L'/`@':B</!PP4!VHN<)"0!``"-M![6P6+*
MB<LQ^S'#P<@"`?.)UL'&!0'SB<:+A"0H`0``C8P!UL%BRHGX,?`QT`'(B=G!
MP04!R(G1BY0D+`$``,')`HV4%];!8LJ)]S'/,=\!UXG"P<(%`=>+E"0P`0``
MP<L"C;06UL%BRHG*,=HQPL'(`@'RB?[!Q@4!\HG&BX0D-`$``(V$`=;!8LJ)
MV3'Q,?G!SP(!P8G0P<`%`<&+A"0X`0``C9P#UL%BRHGP,?@QT`'8B<O!PP4!
MV(G3BY0D/`$``,'+`HML)!"-E!;6P6+*B?XQWC'.P<D"`=:)PL'"!0'6BY0D
M0`$``(V\%];!8LJ)VC'*,<+!R`(!^HGWP<<%`?J)QXN$)$0!``"-A`/6P6+*
MB<LQ^S'SP<X"`<.)T,'`!0'#BX0D2`$``(V,`=;!8LJ)^#'P,=`!R(G9P<$%
M`<B)T8N4)$P!``#!R0*-E!?6P6+*B?<QSS'?P<L"`=>)PL'"!0'7BY0D4`$`
M`(VT%M;!8LJ)RC':,<+!R`(!\HG^P<8%`?*)QHN$)%0!``"-A`'6P6+*B=DQ
M\3'YP<\"`<&)T,'`!0'!BX0D6`$``(V<`];!8LJ)\#'X,=`!V(G+P<,%`=B)
MTXN4)%P!``#!RP*-E!;6P6+*B?XQWC'.P<D"`=:)PL'"!0'6BY0D8`$``(V\
M%];!8LJ)VC'*,<+!R`(!^HGWP<<%`?J+O"1D`0``C;P[UL%BRHG+,<,Q\\'.
M`@'[B=?!QP4!^XN\)&@!``"-O#W6P6+*`<^)P3'Q`W0D%#'1P<H"`U0D#`'Y
MB=\#7"08P<<%`?D#1"0<BWPD"(D/B5\$B4<0B5<(BX0D;`$``&4S!10```")
M=PQT!>A#&```@<1\`0``6UY?7<-55U93,?;HG/+__X'#-7P``(/L'(7`=&Z+
MBQP!``")Q8LQB70D!#'V@WPD!`!T5XI-`(3)=`B`^3UT`T7K\8M\)`2)P2G%
MBS>%]G0ZB50D#%!548E,)!16Z*OM__^#Q!"%P(M,)`B+5"0,=16`/"X]=0\K
M?"0$C70N`<'_`HDZZP6#QP3KP(/$'(GP6UY?7<.#[!R-5"0(98L-%````(E,
M)`PQR>A7____BTPD#&4S#10```!T!>A]%P``@\0<PU=6Z&X7``"!PGI[``!3
MB<.#[!"+NAP!``!EH10```")1"0,,<"-="0(B?*)V.@/____A<!T%XL'BU0D
M"(T$D(M0!(72B1!TX8/`!.ORBT0D#&4S!10```!T!>@:%P``@\006UY?PU57
M5E.#["S\Z'7Q__^!PPY[``")!"2)5"0$9:$4````B40D'#'`,<"`.CV-5"08
M#Y3``40D!(/-_XM\)`0Q]HGIB?#RKO?1C4'_B40D"(L$).B%_O__A<!T,8GI
MB<>)PHGP\JZ)S??533EL)`@/AZP````QP(M<)`2*#`.(#`)`A,EU\3'`Z1`!
M``"+@QP!```Q[8L0@SRJ`'0#1>OW@[N8$0```(UU`G0CP>8"45%64N@=Z___
MBY,<`0``@\00A<")`G5&@\C_Z<X```")5"0,P>8"@^P,5L>#F!$```$```#H
MW.O__X/$$(7`B<=TU8/N"%!6BU0D%%)7Z-/K__^+@QP!``"#Q!").(N#'`$`
M`(L`QT2H!`````");"08BP0DBA"$TG0(@/H]=`-`Z_*+LQP!``"+3"08@^P,
M*T0D#(L6C3R*BTPD%(U$`0)0Z&_K__^#Q!"%P(D'#X1D____BP:+5"08BP20
M_P0DBS0DBE;_A-*($'0(@/H]=`-`Z^G&`#TQTHM\)`2*#!>(3!`!0H3)=?#I
MZ?[__XM<)!QE,QT4````=`7H9A4``(/$+%M>7UW#55=64X'LC````/SHO>__
M_X'#5GD``(G&9:$4````B40D?#'`A?8/A!@!``"`/@`/A`\!``"#[`Q6Z+#I
M__^#Q!"%P(G%#X3Y````C8-%G/__B40D"(V#1)S__XE$)`R#[`Q5Z$;J__^#
MQ!"%P`^$O0```(/`$XD$)%)2_W0D$/]T)`SH%NK__X/$$(7`=-!04/]T)!3_
M="0,Z`#J__^#Q!"%P'2Z@\K_,<")]XG1@^P,\JZ+?"0,]]&)3"00B=&+5"00
M\JZ)R/?0C0P"4>@\ZO__B<>-@T><____="005E!7Z$CL__^#Q!B-1"0D4%?H
M^NO__X/$$$!T&8M$)"PE`/```#T`0```=0F)^.CO_O__ZPR#[`Q7Z.+I__^#
MQ!"#[`Q7Z+;K__^#Q!#I+____X/L#%7H)>K__XDT).AMZ___@\00BT0D?&4S
M!10```!T!>@(%```@<2,````6UY?7<-64XG&Z&/N__^!P_QW``"#['QEH10`
M``")1"1T,<"-1"044%;HQ.G__X/$$(7`=3&+5"0<@>(`\```@?H`0```=`B!
M^@"@``!U&5!0:@)6Z(GH__^#Q!"%P`^4P`^VP.L",<"+3"1L93,-%````'0%
MZ(@3``"#Q'1;7L-3Z.OM__^!PX1W``"#[!2+@Q`!``#_,.@FZ___C9-8V___
M4HV339S___^S+`$``%)0Z.SJ__^#Q"A;PU93Z*_M__^!PTAW``"#[!"+LQ`!
M``#_-NCJZO__B00DZ*#___]8_S;HVNK__UJ-D_B>__]9:@!24HV3F)C__U*-
MDVF<__]24.CZY___@\0D6U[#55=64^A:[?__@</S=@``@>P<(```9:$4````
MB80D#"```#'`Z/OG__^-DWZ<__^#[`Q24(V#@IS__U!H`1```(UT)"96Z)KG
M__^-4`&#Q""!^@$0``!V`@\+A<!Y!#'VZV%2:``0``"-K"03$```55;H+NG_
M_X/$$(7`B<=XWXU``8/L#%#H&>C__X/$$(7`B<9TRCGH<P>-!#@YQ7*Y.>YV
M"(U$/0`YQG*M@?\!$```?Z505U56Z!CJ___&!#X`@\00BXPD#"```&4S#10`
M``")\'0%Z!H2``"!Q!P@``!;7E]=P^D6____55=64X'LC!```/SH:>S__X'#
M`G8``(N4)*00``"+M"2@$```9:$4````B80D?!```#'`C8..G/__B50D!.@@
M^O__B00D4%!J+U;H&^C__X/$$(7`BU0D!'02C8.7G/__B?+HD/K__^DB`0``
MC:NDG/__,<")]X/)__*N4%!54HG/]]?H,NG__XG"C8-%G/__@\00B7PD"(E$
M)`2%TG2[@#H`=02+5"0$@SPD`'0?4%!2B50D&/]T)`SHC.;__X/$$(7`BU0D
M#`^$K0```#'`@\G_B=?RKO?128!\"O\O=0=)Q@0*`.OR`TPD"('Y_P\```^/
M8____XV#IIS__U=75E"-@Y6=__]24&@`$```C;PDF````%?HW^7__T"#Q"`]
M`!```'8"#PM148U$)"105^AEZ/__@\00A<!U/HM$)"PE`/```#T`@```=2Y2
M4FH!5^B4Y?__@\00A<!U'8V#EYS__XGZZ(WY__^#[`Q7Z*?F__^#Q!")QNL4
M4%!5:@#H-NC__X/$$(G"Z0W___^)\(NT)'P0``!E,S44````=`7H91```('$
MC!```%M>7UW#BT0D!(U0`8I*_X3)=`J`^2]U`HG00NOOPU575E.#[`S\BW0D
M(.B?ZO__@<,X=```A?9T-HH6A-)T,#'`@\G_B??RKO?1C40._CG&<Q2`."]U
M"$CK]$@YQG,'@#@O=?;K+3G&=2F`^B]U"X/L#(V#19S__^L)C8.FG/__@^P,
M4.CFY?__@\00ZSF`."]U!4@YQG+V*?"-4`*!^@`0``!W($`]`!```'8"#PM2
M4%:-LY@!``!6Z&'F__^#Q!")\.L",<"#Q`Q;7E]=PU=64X/L,/SH\^G__X'#
MC',``&6A%````(E$)"PQP(V#J)S__XU\)`J-LS3;__^Y(@```/.DZ-WW__^-
M@[&<___HTO?__XV#N9S__^C']___C8/"G/__Z+SW__^-@\F<___HL??__XV#
MV9S__^BF]___C8..G/__Z)OW__^-@^6<___HD/?__XV#[YS__^B%]___C8/Y
MG/__Z'KW__^-@Y><___H;_?__XV#`YW__^@U]___A<!T#8G"C8/OG/__Z+GW
M__^-@Q2=___H&??__X7`=`V)PHV#)IW__^B=]___C8,QG?__Z/WV__^%P'0*
MB<*-@XZ<___K-HV#09W__^CD]O__A<")PG4?C40D&U*-DU*=__]J"E)0Z$+D
M__^#Q!"%P'4/C50D)8V#Y9S__^A)]___C9-=G?__C8/)G/__Z#CW__^+1"0L
M93,%%````'0%Z#D.``"#Q#!;7E_#4^B;Z/__@<,T<@``@^P(@[M4`0``_W4H
MC8/EG/__Z&?V__\QTH7`=`Z*`(3`#Y7"/#`/E<`AP@^VTHF35`$``(N#5`$`
M`(/$"%O#4^A0Z/__@</I<0``@^P(Z//E__^#[`Q0Z$KD__^#Q!`QTH7`=`*+
M$(/$"(G06\-55U93@^P<_.@:Z/__@<.S<0``BW0D,(V#7YW__^CN]?__A<!T
M!X`X`(G%=0V)\HV#7YW__X/$'.M>4%!65>BEX___@\00A<!U5X/*_XGW@^P,
MB='RKHGO]]&)3"08B=&+5"08\JZ)R/?0C0P"4>CUXO__B<>-@Z2<__^)+"10
MC8.5G?__5E!7Z/OD__^-@U^=__^)^H/$/%M>7UWI!/;__X/$'%M>7UW#55=6
M4X'L;($``/SH;N?__X'#!W$``&6A%````(F$)%R!```QP(V#=IW__XNL)("!
M``#'A"24`````````(V\)*0```"-LSP!``"Y!@```(F$)(P```"-@T6<___'
MA"2@`````````/.EB80DD````(V#>YW__XF$))@```"-@X"=__^)A"2<````
MC8..G/__Z-+T__^%P'0A@#@`B<9T&H/L#%#HKO[__XDT).ANXO__B40D%.EB
M`P``Z&G^__^%P(G&C;PDF````'4SBP>%P'0GZ)#T__\Q]H7`=!.`.`!T#H/L
M#%#H-.+__X/$$(G&@\<$A?9TU>L&C;-OG?__,<")]X/)__*N@^P,]]&-1`G_
M4.BHX?__B40D%(/$$(M\)`2-DXF=__^`/@!T'5$/M@9&4%*)5"045X/'`NB>
MX___@\00BU0D".O>C;PDI````(LWA?9T*8GPZ`GT__^%P(G&="6`.`!T(.BD
M]___A<!T%X/L#%;HI.'__X/$$(G&C;PDC````.LT@\<$Z\.+%X72="V`.@!T
M*(G0B50D".AN]___A<"+5"0(=`Z#[`Q2Z&KA__^#Q!")QH/'!(7V=,TQP(/)
M_XGW\JZ+?"0$@^P,]]&)RH/)__*NB<CWT(V\`@($``!7Z-3@__^)1"086(V#
MCIW__UK_="0,4(V#IIS__XE$)!Q0C8.3G?__5E#_="0DZ,?B__^#Q!AHP`$`
M`/]T)!3H5N+__X/$$$!U-^@[XO__@S@1="WH,>+__X/L#/\PC8.<G?___W0D
M&/]U`%"+@_@```#_,.BAX?__@\0@Z1T'``!65HU$)#10_W0D%.B)X/__B40D
M((/$$(-\)!``#X7=!@``BT0D/"4`\```/0!````/A<D&``"+="1$Z(KB__\Y
MQ@^%N`8``(M$)#PE_P$``#W``0``#X6D!@``@^P,5^CUW___B40D%(V#:IW_
M_^B.\O__@\00A<`/A$`!``"#[`Q0Z#+@__]:65#_=0#H#?C__X/$$(7`B<8/
MA!\!```QP(/)_XGW\J[WT8UY_X/_`P^/$`$``.B\^___A<")1"04#X6H!0``
M555J`%;H^-___X/$$(7`B<</A)$%``!J`FK_:NY0Z-_>__^#Q`QJ!HVT)&0!
M``!65^C<X/__@\00@+PD7`$````/A2T!``"`O"1=`0``0P^%'P$``("\)%X!
M``!!#X41`0``@+PD7P$``$,/A0,!``"`O"1@`0``2`^%]0```("\)&$!``!%
M#X7G````:@)J_VK&5^AIWO__@\0,:BE65^AMX/__C8/XGO__65]05O]T)!R-
M@^&=____="0<4/]T)"#HZ^#__X/$((/L#/]T)!3HC.#__XM4)!2-@XZ<___H
MZO'__UC_="00Z#O[__^#Q!#I9P4``(MU`.G9_O__4%"-@]>=__]0C40.^U#H
M$-[__X/$$(7`#X72_O__@_\$=`N`?#[[+P^%PO[__XMM!(7M#X2W_O__,<"#
MR?^)[_*N]]&-0?^#^`,/AJ#^__]04(V#W)W__U"-1`W[4.C`W?__@\00A<`/
MA8+^__^)[NE[_O__:@!J`&H`5^B"W?__QX0DS`````$C16?'A"30````B:O-
M[\>$)-0```#^W+J8QX0DV````'94,A#'A"3<````\.'2P\>$).``````````
MQX0DY`````````#'A"0H`0```````(/$$(V$)%P!``")1"00C80DV````(E$
M)`Q6:`"```#_="085^@1W___@\00A<")Q@^.5P$``(T$]0`````#A"30````
M<P?_A"34````B80DT````(GPP>@=`80DU````(N$)!@!``"%P'1XN4````")
M]2G!.<Y^`HG-`T0D##M$)!!S"8T,*#E,)!!R$#M$)!!V#(M,)!`!Z3G(<P(/
M"X']`(```'?V4E7_="084.@WW___BX0D*`$```'HB80D*`$``(/$$(/X0`^%
M2O___XV$)+P````I[@-L)!#H$^/__^L'C:PD7`$``(V$)!@!``")1"0<@_X_
M?D<[;"0,=@8[;"0<<I<[;"0,<PF-14`Y1"0,<HA0:D"#[D!5@\5`C80DR```
M`(E$)"3_="08Z+?>__^+1"0HZ+CB__^#Q!#KM#ML)`QV#HM$)`P!\#G%#X)(
M____.VPD#',.C40U`#E$)`P/@C3___^#_D0/ARO___]05E7_="08Z&S>__^)
MM"0H`0``@\00Z8S^__^#[`Q7Z(3=__^+K"3@````B[0DY````(GJP>H#@^(_
MC4(!QH04Z````("#Q!"#^#A^.+I`````42G"4FH`C;PDR````(E\)!B-O"3D
M`````?A0Z*;;__^+1"0<Z`?B__^#Q`QJ.&H`5^L34KHX````*<)2:@"-A`3D
M````4.A[V___B?"#Q!#!Z!B(A"00`0``B?#!Z!"(A"01`0``B?#!Z`B(A"02
M`0``B?"-M"0S`0``B(0D$P$``(GHP>@8B?>(A"04`0``B>C!Z!"(A"05`0``
MB>C!Z`B(A"06`0``B>B-JXF=__^(A"07`0``C80DO````.AMX?__BX0DO```
M`(G"B(0D(@$``,'J&(B4)!\!``")PL'J$(B4)"`!``")PHN$),````#!Z@B(
ME"0A`0``B<*(A"0F`0``P>H8B)0D(P$``(G"P>H0B)0D)`$``(G"BX0DQ```
M`,'J"(B4)"4!``")PHB$)"H!``#!ZAB(E"0G`0``B<+!ZA"(E"0H`0``B<*+
MA"3(````P>H(B)0D*0$``(G"B(0D+@$``,'J&(B4)"L!``")PL'J$(B4)"P!
M``")PHN$),P```#!Z@B(E"0M`0``B<*(A"0R`0``P>H8B)0D+P$``(G"P>H0
MB)0D,`$``(G"P>H(B)0D,0$``(V4)!\!``!0BT0D&(E4)!`/M@004%56@\8"
MZ#K<____1"0D@\00@WPD%!2+5"0,==:-@_B>___&A"1;`0```%554(V#IIS_
M_U=0Z0O[__^-DUV=__^-@^6<__^-N_Z=___H$.W__^A.V?__5E:-L_B>__]6
M4(V#\)W___]T)!S_="0<4/]T)"#HS-O__X/$(%)2:,`!``#_="00Z%G;__^#
MQ!!`#X7'^O__Z#K;__^#.!$/A;GZ____1"00Z/C8__]15O]T)!A0_W0D'/]T
M)!Q7_W0D(.A_V___@\0@Z[&-@P^>____="0(_W4`4(N#^````/\PZ'_:__^#
MQ!#'1"0$`````(N,)%R!``!E,PT4````BT0D!'0%Z&L#``"!Q&R!``!;7E]=
MPU575E/HQMW__X'#7V<``(/L*(NS$`$``/\VZ`';__]=_S:)Q^CWVO__BD!D
MB$=EC8/)G/__Z'[K__^#Q!"%P'0+@#@Q=0:`>`$`=`7H?_/__X/L#/\VZ,7:
M__^-DVZ>__]J"VH!4E#H1-G__X/$((7`=2V#[`S_-NBCVO__C9-SGO__:@-J
M`5)0Z"+9__^#Q""%P(G'#X7.````Z0T!``"+0`R_`0```(MH&#N[H!$``(U'
M_XE$)`A]'H/L#/\VZ%S:__]J`/]T)!Q54.C_U___@\0@A<!U&(N#H!$``+\!
M````B40D#$@Y1"0(=87K5(L0BT(()0`$(``]``0``'4%BT(,ZR")5"0,@^P,
M_S;H#-K__VH":@"+5"0D4E#H/=K__X/$(%%14(N#G!$``/\TN.AIU___@\00
MA<!UFD?I9____SN[H!$```^-(____X/L#/\V1^C%V?__65I54.B<UO__@\00
MZ]N+0`R#[`R+*/\VZ*C9__^-DW6>__^#Q`Q255#H1]C__XM'#(/$$(LX]D<*
M0'06@^P,_S;H?]G__UU:5U#H1M?__X/$$(/L#/\VZ&G9__^-DWJ>__]J`VH!
M4E#HZ-?__X/$((7`B<5T9XV#EYS__^C<Z?__A<")QW0%BT4,ZS?H@.[__X7`
MB<>+10QT(8/L#(LH_S;H']G__X/$#%=54.C$U___B3PDZ,S8___K'XN3G!$`
M`(LZBRB#[`S_-NCVV/__@\0,5U50Z)O7__^#Q!"#[`S_-NC>V/__C9-\GO__
M@\0,:@%24.C<U?__6O\VB<?HPMC__XV3D9[__X/$#%)74.AAU___6?\VZ*G8
M___&0&4`C8..G/__Z#+I__^#Q!"%P(F#I!$``'4F@^P,_[.<$0``Z+#S__^#
MQ!"%P(F#I!$``'4+@^P,C8.7GO__ZS=04&C``0``_[.D$0``Z`78__^-4`&#
MQ!"#^@%V((/X$70;4(N#G!$``/^SI!$``/\PC8.XGO__4.AZU?__@\0<6UY?
M7<-75E.+="00Z,7:__^!PUYD``"#[`Q6Z`;P__^)!"3HY>___X/$$(G'Z`/R
M__^%P'0IA?9T)8`^`'0@4%"-@XZ=__]05^A)UO__@\00.<=U"EN)\%Y?Z:KJ
M__];7E_#BQ0DPU/H:=K__X'#`F0``(/L".C\U___@\0(6\-5Z,/;__\%Z6,`
M`(GE4U*-F"#___^#ZP2+`X/X_W0$_]#K\EA;7<.#[`SHI]K__X/$#,,N+@`E
M<R\E<P!$>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI0
M05(Z.D)/3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-
M10`Z`"\`4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.
M251)04Q)6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%2
M7T-!0TA%`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%2
M7U1-4$1)4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@!005)?
M0TQ%04X]`#$`3$1?3$E"4D%265]0051(`%-94U1%30`O=&UP`%5315(`55-%
M4DY!344`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO;B!O9B!P<FEV
M871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`<&%R;``N
M<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M)74M
M)74E<P`E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*`%1%
M35!$25(`5$U0`$%21U8`&`!P97)L`#``4$%2.CI086-K97(Z.E9%4E-)3TX`
M,2XP-#4`56YA8FQE('1O(&-R96%T92!C86-H92!D:7)E8W1O<GD`)7,Z(&-R
M96%T:6]N(&]F('!R:79A=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE
M9"`H97)R;F\])6DI"@`M90`M+0!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@
M("U3("0P("1[,2LB)$`B?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S
M;VUE('-H96QL"G!A8VMA9V4@7U]P87)?<&P["FUY("@D<&%R7W1E;7`L("1P
M<F]G;F%M92P@0'1M<&9I;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]
M*2!["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*<F5Q=6ER92!&:6QE.CI3<&5C.PIM>2`D=&]P9&ER(#T@1FEL93HZ0F%S
M96YA;64Z.F1I<FYA;64H)'!A<E]T96UP*3L*;W5T<RAQ<7M296UO=FEN9R!F
M:6QE<R!I;B`B)'!A<E]T96UP(GTI.PI&:6QE.CI&:6YD.CIF:6YD9&5P=&@H
M<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A<E]T96UP*3L*
M<FUD:7(@)'!A<E]T96UP.PII9B`H+60@)'!A<E]T96UP("8F("1>3R!N92`G
M35-7:6XS,B<I('L*;7D@)'1M<"`](&YE=R!&:6QE.CI496UP*`I414U03$%4
M12`]/B`G=&UP6%A86%@G+`I$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA
M;64H)'1O<&1I<BDL"E-51D9)6"`]/B`G+F-M9"<L"E5.3$E.2R`]/B`P+`HI
M.PIP<FEN="`D=&UP("(C(2]B:6XO<V@*>#TQ.R!W:&EL92!;(%PD>"`M;'0@
M,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?
M=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@
M,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE("X@(B<*(CL*8VAM;V0@
M,#<P,"PD=&UP+3YF:6QE;F%M93L*;7D@)&-M9"`]("1T;7`M/F9I;&5N86UE
M("X@)R`^+V1E=B]N=6QL(#(^)C$@)B<["F-L;W-E("1T;7`["G-Y<W1E;2@D
M8VUD*3L*;W5T<RAQ<2A3<&%W;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P
M97)F;W)M(&-L96%N=7`Z("D*+B`D=&UP+3YF:6QE;F%M92D["GT*?2!]"D)%
M1TE.('L*26YT97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E
M<FYA;',Z.E!!4CHZ0D]/5#L*979A;"!["E]P87)?:6YI=%]E;G8H*3L*;7D@
M)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;7D@)4-O;F9I9R`]("@*<&%T
M:%]S97`@("`@/3X@*"1>3R`]?B`O7DU35VEN+R`_("<[)R`Z("<Z)RDL"E]E
M>&4@("`@("`@(#T^("@D7D\@/7X@+UXH/SI-4U=I;GQ/4S)\8WEG=VEN*2\@
M/R`G+F5X92<@.B`G)RDL"E]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-4U=I
M;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["E]S971?<')O9VYA;64H*3L*7W-E
M=%]P87)?=&5M<"@I.PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PIL
M;V-A;"`D4TE'>U]?5T%23E]??2`]('-U8B![?3L*;W!E;B!?1D@L("<\)RP@
M)'!R;V=N86UE(&]R(&QA<W0["F)I;FUO9&4H7T9(*3L*;7D@)&)U9CL*;7D@
M)'-I>F4@/2`M<R`D<')O9VYA;64["FUY("1O9F9S970@/2`U,3(["FUY("1I
M9'@@/2`M,3L*=VAI;&4@*#$I"GL*)&]F9G-E="`]("1S:7IE(&EF("1O9F9S
M970@/B`D<VEZ93L*<V5E:R!?1D@L("TD;V9F<V5T+"`R(&]R(&1I92!Q<5MS
M965K(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=.PIM>2`D;G)E860@/2!R
M96%D(%]&2"P@)&)U9BP@)&]F9G-E=#L*9&EE('%Q6W)E860@9F%I;&5D(&]N
M("(D<')O9VYA;64B.B`D(5T@=6YL97-S("1N<F5A9"`]/2`D;V9F<V5T.PHD
M:61X(#T@<FEN9&5X*"1B=68L(")<;E!!4BYP;5QN(BD["FQA<W0@:68@)&ED
M>"`^/2`P('Q\("1O9F9S970@/3T@)'-I>F4@?'P@)&]F9G-E="`^(#$R."`J
M(#$P,C0["B1O9F9S970@*CT@,CL*?0IL87-T('5N;&5S<R`D:61X(#X](#`[
M"B1O9F9S970@+3T@)&ED>"`M(#0["G-E96L@7T9(+"`M)&]F9G-E="P@,CL*
M<F5A9"!?1D@L("1B=68L(#0["G-E96L@7T9(+"`M)&]F9G-E="`M('5N<&%C
M:R@B3B(L("1B=68I+"`R.PIR96%D(%]&2"P@)&)U9BP@-#L*)&1A=&%?<&]S
M(#T@*'1E;&P@7T9(*2`M(#0["FUY("5R97%U:7)E7VQI<W0["G=H:6QE("@D
M8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A9"!?1D@L
M("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@/2`D8G5F
M.PIO=71S*'%Q*%5N<&%C:VEN9R!F:6QE("(D9G5L;&YA;64B+BXN*2D["FUY
M("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO?'P@*2`_
M("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L(#0["G)E
M860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E9FEN960H
M)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I*2!["FUY
M("1F:6QE;F%M92`](%]T96UP9FEL92@B)&-R8R1E>'0B+"`D8G5F+"`P-S4U
M*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9G5L;&YA;65](#T@)&9I;&5N
M86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F:6QE;F%M97T@/2`D9G5L
M;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@/7X@;7Q>+S]S:&QI8B]\(&%N
M9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@>PIM>2`D9FEL96YA;64@/2!?
M=&5M<&9I;&4H(B1B87-E;F%M921E>'0B+"`D8G5F+"`P-S4U*3L*;W5T<R@B
M4TA,24(Z("1F:6QE;F%M95QN(BD["GT*96QS92!["B1R97%U:7)E7VQI<W1[
M)&9U;&QN86UE?2`]"B1005(Z.DAE879Y.CI-;V1U;&5#86-H97LD9G5L;&YA
M;65](#T@>PIB=68@/3X@)&)U9BP*8W)C(#T^("1C<F,L"FYA;64@/3X@)&9U
M;&QN86UE+`I].PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@
M/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@
M<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1F:6QE;F%M92`](&1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*;7D@)&ME>3L*9F]R
M96%C:"`H:V5Y<R`E<F5Q=6ER95]L:7-T*2!["FYE>'0@=6YL97-S("]<421M
M;V1U;&5<120O.PHD:V5Y(#T@)%\[(&QA<W0["GT*9&5L971E("1R97%U:7)E
M7VQI<W1[)&ME>7T@:68@9&5F:6YE9"@D:V5Y*3L*?2!O<B!R971U<FX["B1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["FEF
M("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&:6QE.CIN97<I
M*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL92!O<B!D:64@)"$[
M"F)I;FUO9&4H)&9H*3L*<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["G-E
M96LH)&9H+"`P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N
M86UE(#T@7W1E;7!F:6QE*"(D9FEL96YA;64M/GMC<F-]+G!M(BP@)&9I;&5N
M86UE+3Y[8G5F?2D["F]P96X@;7D@)&9H+"`G/"<L("1F:6QE;F%M92!O<B!D
M:64@(F-A;B=T(')E860@)&9I;&5N86UE.B`D(2(["F)I;FUO9&4H)&9H*3L*
M<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN
M;W0@9FEN9"`D;6]D=6QE(5QN(CL*?2P@0$E.0RD["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P.CI(96%V>3L*
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y
M;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@*&UY("1F:6QE
M;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI('L*=6YL97-S
M("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO*2![
M"FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U:7)E("1F:6QE
M;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D9FEL96YA;64@
M/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@)')E<75I<F5?
M;&ES='LD9FEL96YA;65].PI]"FQA<W0@=6YL97-S("1B=68@97$@(E!+7#`P
M,UPP,#0B.PHD<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0["GT*;7D@0'!A
M<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?;F%M
M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2
M155312!M87D@8F4@82!S96-U<FET>2!P<F]B;&5M*0HD<75I970@/2`P('5N
M;&5S<R`D14Y6>U!!4E]$14)51WT["FEF("@A)'-T87)T7W!O<R!O<B`H)$%2
M1U9;,%T@97$@)RTM<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PIM>2`E9&ES
M=%]C;60@/2!Q=R@*<"`@(&)L:6)?=&]?<&%R"FD@("!I;G-T86QL7W!A<@IU
M("`@=6YI;G-T86QL7W!A<@IS("`@<VEG;E]P87(*=B`@('9E<FEF>5]P87(*
M*3L*:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*<VAI
M9G0@0$%21U8["B1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*
M?0IE;'-E('L@(R!N;W)M86P@<&%R;"!B96AA=FEO=7(*;7D@0&%D9%]T;U]I
M;F,["G=H:6QE("A`05)'5BD@>PHD05)'5ELP72`]?B`O7BTH6T%)34]"3&)Q
M<&EU<U1V72DH+BHI+R!O<B!L87-T.PII9B`H)#$@97$@)TDG*2!["G!U<V@@
M0&%D9%]T;U]I;F,L("0R.PI]"F5L<VEF("@D,2!E<2`G32<I('L*979A;"`B
M=7-E("0R(CL*?0IE;'-I9B`H)#$@97$@)T$G*2!["G5N<VAI9G0@0'!A<E]A
M<F=S+"`D,CL*?0IE;'-I9B`H)#$@97$@)T\G*2!["B1O=70@/2`D,CL*?0IE
M;'-I9B`H)#$@97$@)V(G*2!["B1B=6YD;&4@/2`G<VET92<["GT*96QS:68@
M*"0Q(&5Q("=")RD@>PHD8G5N9&QE(#T@)V%L;"<["GT*96QS:68@*"0Q(&5Q
M("=Q)RD@>PHD<75I970@/2`Q.PI]"F5L<VEF("@D,2!E<2`G3"<I('L*;W!E
M;B`D;&]G9F@L("(^/B(L("0R(&]R(&1I92`B6%A8.B!#86YN;W0@;W!E;B!L
M;V<Z("0A(CL*?0IE;'-I9B`H)#$@97$@)U0G*2!["B1C86-H95]N86UE(#T@
M)#(["GT*<VAI9G0H0$%21U8I.PII9B`H;7D@)&-M9"`]("1D:7-T7V-M9'LD
M,7TI('L*9&5L971E("1%3E9[)U!!4E]414U0)WT["FEN:71?:6YC*"D["G)E
M<75I<F4@4$%2.CI$:7-T.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@I('5N;&5S
M<R!`05)'5CL*)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`05)'5CL*
M97AI=#L*?0I]"G5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["GT*?0II9B`H
M)&]U="D@>PI["G)E<75I<F4@24\Z.D9I;&4["G)E<75I<F4@07)C:&EV93HZ
M6FEP.PI]"FUY("1P87(@/2!S:&EF="A`05)'5BD["FUY("1Z:7`["FEF("AD
M969I;F5D("1P87(I('L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H,3(X
M*C$P,C0I.PIO<&5N(&UY("1F:"P@)SPG+"`D<&%R(&]R(&1I92`B0V%N;F]T
M(&9I;F0@)R1P87(G.B`D(2(["F)I;FUO9&4H)&9H*3L*8FQE<W,H)&9H+"`G
M24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M
M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII
M<#HZ05I?3TLH*2`I"F]R(&1I92`B4F5A9"`G)'!A<B<@97)R;W(Z("0A(CL*
M?0IM>2`E96YV(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP
M+3YC;VYT96YT<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD
M+R]M<SL*)&UE=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ
M72LI.B`H+BLI)"]M9SL*?0I].PIL;V-A;"`D+R`](%PT.PII9B`H9&5F:6YE
M9"`D<&%R*2!["F]P96X@4$%2+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A
M<B(["F)I;FUO9&4H4$%2*3L*9&EE("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE
M(B!U;FQE<W,@/%!!4CX@97$@(E!+7#`P,UPP,#0B.PI]"D-R96%T95!A=&@H
M)&]U="D@.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL
M93HZ3U]#4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL
M93HZ3U]44E5.0R@I+`HP-S<W+`HI(&]R(&1I92`D(3L*8FEN;6]D92@D9F@I
M.PHD+R`]("AD969I;F5D("1D871A7W!O<RD@/R!<)&1A=&%?<&]S(#H@=6YD
M968["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^
M.PII9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_
M.B,A?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`[
M"E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@
M)#`I"GT*9F]R96%C:"!M>2`D:V5Y("AS;W)T(&ME>7,@)65N=BD@>PIM>2`D
M=F%L(#T@)&5N=GLD:V5Y?2!O<B!N97AT.PHD=F%L(#T@979A;"`D=F%L(&EF
M("1V86P@/7X@+UY;)R)=+SL*;7D@)&UA9VEC(#T@(E]?14Y67U!!4E\B("X@
M=6,H)&ME>2D@+B`B7U\B.PIM>2`D<V5T(#T@(E!!4E\B("X@=6,H)&ME>2D@
M+B`B/21V86PB.PHD;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B1M86=I8R`N
M("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E="DI*0I]
M96<["GT*)&9H+3YP<FEN="@D;&]A9&5R*3L*)"\@/2!U;F1E9CL*:68@*"1B
M=6YD;&4I('L*<F5Q=6ER92!005(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["FEN:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I
M.PIM>2!`:6YC(#T@9W)E<"![("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L
M92!N92`G<VET92<I(&]R"B@D7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI
M8F5X<'T@86YD"B1?(&YE("1#;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D[
M"GT@0$E.0SL*;7D@)69I;&5S.PHD9FEL97-[)%]]*RL@9F]R($!$>6YA3&]A
M9&5R.CID;%]S:&%R961?;V)J96-T<RP@=F%L=65S("5)3D,["FUY("1L:6)?
M97AT(#T@)$-O;F9I9SHZ0V]N9FEG>VQI8E]E>'1].PIM>2`E=W)I='1E;CL*
M9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&YA;64L("1F:6QE
M*3L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D;F%M92`]("1005(Z
M.DAE879Y.CI&=6QL0V%C:&5[)%]]*2!["B1F:6QE(#T@)%\["FQA<W0["GT*
M96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO:2D@>PHH)&9I;&4L
M("1N86UE*2`]("@D,2P@)#(I.PIL87-T.PI]"F5L<VEF("AM(5XO;&]A9&5R
M+UM>+UTK+R@N*EM>0V-=*5Q:(2D@>PII9B`H;7D@)')E9B`]("1005(Z.DAE
M879Y.CI-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H)')E
M9BP@)#$I.PIL87-T.PI]"F5L<VEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"FYE>'0@
M=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I='1E;GLD;F%M97TK
M*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB
M7V5X=%Q%)"\["F]U=',H(&IO:6X@(B(L"G%Q*%!A8VMI;F<@(BDL(')E9B`D
M9FEL92`_("1F:6QE+3Y[;F%M97T@.B`D9FEL92P*<7$H(BXN+BD**3L*;7D@
M)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M
M/GMB=69].PI]"F5L<V4@>PIO<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["F)I;FUO9&4H1DE,12D["B1C;VYT
M96YT(#T@/$9)3$4^.PIC;&]S92!&24Q%.PI005(Z.D9I;'1E<CHZ4&]D4W1R
M:7`M/FYE=RT^87!P;'DH7"1C;VYT96YT+"`D9FEL92D*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0IO=71S*'%Q*%=R:71T96X@87,@(B1N86UE
M(BDI.PHD9F@M/G!R:6YT*")&24Q%(BD["B1F:"T^<')I;G0H<&%C:R@G3B<L
M(&QE;F=T:"@D;F%M92D@*R`Y*2D["B1F:"T^<')I;G0H<W!R:6YT9B@*(B4P
M.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL
M("1N86UE"BDI.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&-O;G1E
M;G0I*2D["B1F:"T^<')I;G0H)&-O;G1E;G0I.PI]"GT*)'II<"T^=W)I=&54
M;T9I;&5(86YD;&4H)&9H*2!I9B`D>FEP.PHD8V%C:&5?;F%M92`]('-U8G-T
M<B`D8V%C:&5?;F%M92P@,"P@-#`["FEF("@A)&-A8VAE7VYA;64@86YD(&UY
M("1M=&EM92`]("AS=&%T*"1O=70I*5LY72D@>PIM>2`D8W1X(#T@979A;"![
M(')E<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\
M?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^
M;F5W('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ
M340U+3YN97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z
M.E-(03HZ5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N
M,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL
M92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*?0IE;'-E('L*:68@*"1C='@@86YD
M(&]P96XH;7D@)&9H+"`B/"1O=70B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M
M/F%D9&9I;&4H)&9H*3L*8VQO<V4H)&9H*3L*?0I]"B1C86-H95]N86UE(#T@
M)&-T>"`_("1C='@M/FAE>&1I9V5S="`Z("1M=&EM93L*?0HD8V%C:&5?;F%M
M92`N/2`B7#`B('@@*#0Q("T@;&5N9W1H("1C86-H95]N86UE*3L*)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*)&9H+3YP<FEN="@D8V%C:&5?;F%M92D["B1F
M:"T^<')I;G0H<&%C:R@G3B<L("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*2DI.PHD9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B1F:"T^8VQO<V4["F-H
M;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!
M4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z
M.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1Z:7`@/2!!<F-H
M:79E.CI::7`M/FYE=SL*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL*)&9H+3YF
M9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE("(D(3H@)$`B.PHD>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["G!U<V@@0%!!4CHZ
M3&EB0V%C:&4L("1Z:7`["B1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97T@/2`D
M>FEP.PHD<75I970@/2`A)$5.5GM005)?1$5"54=].PIO=71S*'%Q*%PD14Y6
M>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I*3L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I
M;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE
M>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]
M("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@
M/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO
M*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q*%-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(BDI.PI](&5L<V4@>PIO=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B*2D["B1M96UB97(M/F5X=')A8W14;T9I;&5.
M86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E<W1?;F%M92D@:68@
M)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"1005(Z.DQI8D-A8VAE
M>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@0$%21U8["E5S86=E
M.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-;6]D=6QE(%T@6R!S
M<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM8B!=(%LM3V]U=&9I
M;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@
M/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E4&%T:"!["FUY("@D
M;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M93L*;7D@*"1B87-E
M;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I;&5P87)S
M92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z.E!A=&@["D9I;&4Z
M.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A
M=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?;6]D=6QE<R!["G)E
M<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E<75I<F4@:6YT96=E
M<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN9W,["G)E<75I<F4@
M=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z.DAE879Y.PIR97%U
M:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V>3L*<F5Q=6ER92!%
M>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&:6QE.CI496UP.PIR
M97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D97(["G)E<75I<F4@
M0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I<F4@24\Z.D9I;&4[
M"G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PIR97%U:7)E(%!!4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I
M<F4@4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U
M=&5S.PIE=F%L('L@<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN
M,S(@?3L*979A;"![(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R
M97%U:7)E($%R8VAI=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER
M92!4:64Z.DAA<V@Z.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!0
M97)L24\[(')E<75I<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I
M<F4@=71F."!].PI]"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@
M)$5.5GM005)?5$5-4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@
M>PHD<&%R7W1E;7`@/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@
M*`HH;6%P("1%3E9[)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)
M4B!414U0(%1-4"`I*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT
M('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A
M=&@["FUY("1U<V5R;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`]
M(&=E='!W=6ED*"0^*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F
M5VEN,S(Z.DQO9VEN3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G
M:6Y.86UE.PI]"F5L<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@
M/2`D<'=U:60["GT*96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]
M('Q\("1%3E9[55-%4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O
M7%<O7R]G.PIM>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A
M<BTB+G5N<&%C:R@B2"HB+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@
M,#<U-3L*:68@*"$D14Y6>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS
M=&%T*"1P<F]G;F%M92DI6SE=*2!["F]P96X@*&UY("1F:"P@(CPB+B`D<')O
M9VYA;64I.PIS965K("1F:"P@+3$X+"`R.PIS>7-R96%D("1F:"P@;7D@)&)U
M9BP@-CL*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@)&9H+"`M-3@L
M(#(["G-Y<W)E860@)&9H+"`D8G5F+"`T,3L*)&)U9B`]?B!S+UPP+R]G.PHD
M<W1M<&1I<B`N/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("1B=68["GT*
M96QS92!["FUY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03L@
M1&EG97-T.CI32$$M/FYE=R@Q*2!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ4TA!,3L@1&EG97-T.CI32$$Q+3YN97<@?0I\?"!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.DU$-3L@1&EG97-T.CI-1#4M/FYE=R!].PIM>2`D<VAA7W9E
M<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*
M:68@*"1S:&%?=F5R<VEO;B!E<2`G-2XS."<@;W(@)'-H85]V97)S:6]N(&5Q
M("<U+C,Y)RD@>PHD8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H
M)&-T>"D["GT*96QS92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD
M<')O9VYA;64B*2D@>PIB:6YM;V1E*"1F:"D["B1C='@M/F%D9&9I;&4H)&9H
M*3L*8VQO<V4H)&9H*3L*?0I]"B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE
M("D["GT*8VQO<V4H)&9H*3L*?0IE;'-E('L*)$5.5GM005)?0TQ%04Y](#T@
M,3L*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?71E;7`M)"0B.PI]"B1%
M3E9[4$%27U1%35!](#T@)'-T;7!D:7(["FUK9&ER("1S=&UP9&ER+"`P-S4U
M.PIL87-T.PI]"B1P87)?=&5M<"`]("0Q(&EF("1%3E9[4$%27U1%35!](&%N
M9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\["GT*<W5B(%]T96UP9FEL92![
M"FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN
M86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE
M*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F
M:"P@)SXG+"`D=&5M<&YA;64@;W(@9&EE(")C86XG="!W<FET92`D=&5M<&YA
M;64Z("0A(CL*8FEN;6]D92`D9F@["G!R:6YT("1F:"`D8V]N=&5N=',["F-L
M;W-E("1F:#L*8VAM;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M
M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D
M=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O
M9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%
M3E9[4$%27U!23T=.04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$[
M"GT*)'!R;V=N86UE('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I
M;F1E>"@D<')O9VYA;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G
M;F%M92`]('-U8G-T<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1#
M;VYF:6=[7V1E;&EM?2D@*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%
M?2!O<B!I;F1E>"@D<')O9VYA;64L("1#;VYF:6=[7V1E;&EM?2D@/CT@,"D@
M>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I
M9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D0V]N9FEG>U]E>&5](BD@
M>PHD<')O9VYA;64@+CT@)$-O;F9I9WM?97AE?3L*<F5T=7)N.PI]"GT*9F]R
M96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P?5Q%+RP@
M)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]414U0?2!A
M;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1)$-O;F9I
M9WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D
M96QI;7TD<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"FEF("US("(D
M9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B@H
M)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]
M"GT*<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.
M5GM005)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D
M*2`_(%=I;C,R.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P
M<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P
M=V0D0V]N9FEG>U]D96QI;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O
M9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.
M251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@
M0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=67S`@*2`I('L*
M9&5L971E("1%3E9[)U!!4E\G+B1??3L*?0IF;W(@*'%W+R!435!$25(@5$5-
M4"!#3$5!3B!$14)51R`O*2!["B1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!
M4E]'3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT["GT*;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@
M("`@("`@("`@("(["FEF("@D14Y6>U!!4E]414U0?2D@>PID96QE=&4@)$5.
M5GM005)?0TQ%04Y].PI]"F5L<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!
M3%]#3$5!3GTI('L*;7D@)'9A;'5E(#T@<W5B<W1R*"1P87)?8VQE86XL(#$R
M("L@;&5N9W1H*")#3$5!3B(I*3L*)$5.5GM005)?0TQ%04Y](#T@)#$@:68@
M)'9A;'5E(#U^("]>4$%27T-,14%./2A<4RLI+SL*?0I]"G-U8B!O=71S('L*
M<F5T=7)N(&EF("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@
M(D!?7&XB.PI]"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I
M;F,@>PIR97%U:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L
M(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV
M;&EB97AP('-I=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V
M96YD;W)L:6)E>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU
M;G-H:69T($!)3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A
M<E]A<F=S*3L*9&EE('%Q*'!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP
M="`B)'!R;V=N86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN*0IU
M;FQE<W,@+64@)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H
M)#$I(&EF("@D0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I
M9B`D0#L*?3L*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H
M)#$I(&EF("@D.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*
M9&EE("0Z.E]?15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH``%]?
M14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@`````'!E<FQX<VDN8P``
M``$;`SO8````&@```!25___T````Q)C__Q@!``#<F/__M`P``'Z<__\L`0``
M7*C__VP!``#LJ/__N`$``!NI___0`0``@:G__P0"```VJ___=`(``)>L__\\
M`P``$JW__X@#``!-K?__N`,``*"M__\$!```A:[__Y`$``"*KO__I`0``#JP
M__^(!0``4[#__YP%```$L?__^`4``&*R__\\!@``K;+__UP&``#<LO__B`8`
M`(6S__\(!P``-+W__]P*```RP/__8`P``)#`___X#```E,#__PP-```4````
M``````%Z4@`!?`@!&PP$!(@!```@````'````!B4__^P`P````X(1@X,2@\+
M=`1X`#\:.RHR)"(0````0````*27__\8`````````#P```!4````2IO__]X+
M````00X(A0)!#@R'`T,.$(8$00X4@P5&#I`#`\T+#A1!PPX00<8.#$''#@A!
MQ0X$``!(````E````.BF__^0`````$$."(4"00X,AP-!#A"&!$$.%(,%4`XP
M?0XT00XX00X\10Y`2`XP:0X40\,.$$'&#@Q!QPX(0<4.!```%````.`````L
MI___+P````!##B!K#@0`,````/@```!#I___9@````!!#@B'`D$.#(8#3`X0
M@P1%#B`"3PX00<,.#$'&#@A!QPX$`&P````L`0``=:?__[4!````00X(A0)!
M#@R'`T$.$(8$00X4@P5##D`"IPY$00Y(00Y,00Y03@Y`6`Y,00Y04@Y`2@Y$
M00Y(10Y,00Y03@Y`=`Y,4@Y02`Y``ED.%$'##A!!Q@X,0<<."$'%#@0```#$
M````G`$``+JH__]A`0```$$."(4"00X,AP-!#A"&!$$.%(,%1@Z@`6X.K`%!
M#K`!2`Z@`6$.K`%!#K`!2`Z@`4\.I`%!#J@!1`ZL`40.L`%(#J`!10ZD`4$.
MJ`%$#JP!1`ZP`4@.H`%0#JP!7`ZP`5$.M`%!#K@!00Z\`4$.P`%(#J@!10ZL
M`4$.L`%(#J`!7PZL`4$.L`%(#J`!0PZL`4$.L`%(#J`!2`ZL`4$.L`%0#J`!
M6`X40<,.$$'&#@Q!QPX(0<4.!$@```!D`@``4ZG__WL`````00X(A@)!#@R#
M`U`.B`%1#HP!00Z0`4@.@`%?#H0!00Z(`4(.C`%!#I`!2`Z``6$.#$'##@A!
MQ@X$```L````L`(``(*I__\[`````$$."(,"3@X<2`X@3`XD3`XH00XL00XP
M2`X(0<,.!`!(````X`(``(VI__]3`````$$."(8"00X,@P-.#AQ(#B!.#AQ"
M#B!&#AQ'#AA"#AQ!#B!!#B1'#BA'#BQ!#C!(#@Q!PPX(0<8.!```B````"P#
M``"4J?__Y0````!!#@B%`D$.#(<#00X0A@1!#A2#!5$.L$!=#KQ`00[`0$$.
MQ$!'#LA`10[,0$4.T$!+#K!`4PZT0$4.N$!(#KQ`00[`0$@.L$!,#KQ`00[`
M0$@.L$!F#K1`00ZX0$$.O$!!#L!`3`ZP0%T.%$'##A!!Q@X,0<<."$'%#@00
M````N`,``.VI__\%`````````.````#,`P``WJG__[`!````00X(A0)!#@R'
M`T$.$(8$00X4@P5&#J`A?`ZD(4$.J"%"#JPA00ZP(4@.H"%J#J0A00ZH(4$.
MK"%!#K`A5`Z@(5P.I"%!#J@A00ZL(4@.L"%(#J`A?0ZD(4$.J"%!#JPA00ZP
M(4<.M"%!#K@A10Z\(4@.P"%)#J`A2@ZD(4$.J"%%#JPA00ZP(4@.H"%5#J0A
M00ZH(4(.K"%!#K`A2`Z@(50.K"%!#K`A2`Z@(44.I"%!#J@A00ZL(4(.L"%(
M#J`A9`X40<,.$$'&#@Q!QPX(0<4.!!````"P!```JJK__QD`````````6```
M`,0$``"OJO__L0````!!#@B%`D$.#(<#00X0A@1!#A2#!4,.(`)-"@XL2`M)
M#BQ!#C!(#B!D#B1!#BA!#BQ'#C!(#B!)#A1!PPX00<8.#$''#@A!Q0X$``!`
M````(`4```2K__]>`0```$$."(<"00X,A@-!#A"#!$,.0`,)`0Y$2`Y(00Y,
M00Y02`Y`>0X00<,.#$'&#@A!QPX$`!P```!D!0``'JS__TL`````00X(@P).
M#A!Z#@A!PPX$*````(0%``!)K/__+P````!!#@B#`DX.$$@.'$$.($@.$$L.
M"$/##@0```!\````L`4``$RL__^I`````$$."(4"00X,AP-!#A"&!$$.%(,%
M0PXP<0H.%$(+00XT00XX00X\00Y`2`XP3`X\7`Y`40Y$1PY(00Y,00Y04`X4
M0<,.$$'&#@Q!QPX(0<4.!$4.,(,%A0*&!(<#0PX40<,.$$'&#@Q!QPX(0<4.
M!-`#```P!@``=:S__Z\)````00X(A0)!#@R'`T$.$(8$00X4@P5&#H"#`@*9
M"@Z,@P)!#I"#`E8+:PZ,@P)!#I"#`D@.@(,"70Z,@P)'#I"#`DP.@(,"4`Z$
M@P)%#HB#`D$.C(,"10Z0@P)+#H"#`G$.C(,"00Z0@P)(#H"#`G$.C(,"00Z0
M@P)(#H"#`ED.C(,"50Z0@P)*#HR#`D<.B(,"1`Z,@P)!#I"#`DL.E(,"1PZ8
M@P)!#IR#`D0.H(,"2`Z(@P)%#HR#`D0.D(,"2`Z`@P)5#HR#`D(.D(,"2@Z4
M@P)##IB#`D$.G(,"2`Z@@P)(#H"#`D8.A(,"00Z(@P)%#HR#`D0.D(,"3`Z`
M@P("1PZ,@P)!#I"#`E<.@(,"2PZ,@P)!#I"#`D8.C(,"00Z(@P)!#HR#`D,.
MD(,"2`Z`@P)S#H2#`D$.B(,"0@Z,@P)!#I"#`D@.@(,"3`Z$@P)"#HB#`D(.
MC(,"00Z0@P)(#H2#`D(.B(,"2`Z,@P)!#I"#`D@.@(,"`E8.A(,"0@Z(@P)"
M#HR#`D$.D(,"2`Z$@P)"#HB#`D$.C(,"00Z0@P),#HR#`D$.B(,"00Z,@P)!
M#I"#`D0.E(,"2@Z8@P)!#IR#`D0.H(,"2`Z`@P)##HR#`D0.D(,"50Z,@P)$
M#I"#`D@.@(,"3@Z$@P)!#HB#`D<.C(,"10Z0@P)(#H"#`GL.A(,"00Z(@P)'
M#HR#`D4.D(,"2`Z`@P)1#H2#`D(.B(,"0@Z,@P)!#I"#`@)@#H"#`E<.A(,"
M10Z(@P)$#HR#`D$.D(,"2`Z`@P("?`Z$@P)!#HB#`D0.C(,"00Z0@P)8#H"#
M`@)0#H2#`D(.B(,"1`Z,@P)2#I"#`E$.@(,"=`Z$@P)!#HB#`D$.C(,"1`Z0
M@P)/#H"#`D@*#HR#`D$.D(,":0Z`@P)+#H2#`D,.B(,"0@Z,@P)5#I"#`E$.
MA(,"0@Z(@P)"#HR#`D$.D(,"0@M!#H2#`D@.B(,"0@Z,@P)(#I"#`DH.@(,"
M`W4!"@Z$@P)-#HB#`D$.C(,"00Z0@P)/#H"#`EH.A(,"00Z(@P)!#HR#`D<.
MD(,"00Z4@P)%"UT.A(,"00Z(@P)'#HR#`D$.D(,"2@Z4@P)$#IB#`D$.G(,"
M1`Z@@P)(#H"#`D$.A(,"00Z(@P)%#HR#`D0.D(,"2`Z`@P)?#H2#`D$.B(,"
M1`Z,@P)!#I"#`D0.E(,"1`Z8@P)!#IR#`D0.H(,"2`Z`@P),#H2#`D,.B(,"
M00Z,@P)(#I"#`D@.@(,"9PX40<,.$$'&#@Q!QPX(0<4.!```@`$```0*``!0
MLO___@(```!!#@B%`D$.#(<#00X0A@1!#A2#!4X./$@.0$8./$(.0%L.,%<.
M/$(.0$T.1$(.2$$.3$$.4$@.,$<./$(.0$T.1$(.2$$.3$$.4$@.,&P./$(.
M0$<.1$0.2$$.3$$.4$@.,'D./$(.0$<.1$(.2$4.3$$.4$@.,$$.-$$..$$.
M/$D.0$@.,%D./$(.0$<./$$..$$./$$.0$@.,$@./$0.0$X.-$$..$$./$$.
M0$L.,$L./$(.0$8./$$..$$./$$.0$@.,$,./$(.0$T.1$(.2$$.3$$.4$@.
M,&T*#CQ$#D!(#C1!#CA!#CQ!#D!/"TT./$(.0$@.-$$..$$./$$.0$@.,$,*
M#CQ"#D!.#C1"#CA!#CQ!#D!&#CQ"#D!0#C1!#CA!#CQ!#D!&#CQ"#D!7#C!-
M#CQ&#D!(#C!-#CQ("T$.-$$..$4./$8.0$L.,$L.-$P..$(./$<.0$4.,$,.
M%$'##A!!Q@X,0<<."$'%#@0``%````"("P``RK/__UX`````00X(AP)!#@R&
M`T$.$(,$4@X<00X@4`X050X400X81PX<00X@2`X010K##@Q#Q@X(0<<.!$4+
M0<,.#$'&#@A!QPX$`$````#<"P``((S__]H!````1`P!`$H0!0)U`$8/`W5P
M!A`'`G5\$`8"=7@0`P)U=`.^`<$,`0!!PT'&0<=!Q4,,!`0`$````"`,``"0
ML___!``````````<````-`P``("S__\9`````$$."(,"3@X02`X(0<,.!```
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````_____P````#_____```````````!`````0````$```#7`@``
M#P```%,$```,````+`\```T`````.P``]?[_;TP!```%````*`@```8````(
M`@``"@```'$$```+````$````!4``````````P```,B>```"````T`$``!0`
M```1````%P```%P-```1````G`P``!(```#`````$P````@````8````````
M`/O__V\!```(^O__;PH`````````````````````````````````````````
M````````````````^)T`````````````5@\``&8/``!V#P``A@\``)8/``"F
M#P``M@\``,8/``#6#P``Y@\``/8/```&$```%A```"80```V$```1A```%80
M``!F$```=A```(80``"6$```IA```+80``#&$```UA```.80``#V$```!A$`
M`!81```F$0``-A$``$81``!6$0``9A$``'81``"&$0``EA$``*81``"V$0``
MQA$``-81``#F$0``]A$```82```6$@``)A(``#82``!&$@``5A(``&82``!V
M$@``AA(``)82``"F$@``MA(``,82``#6$@``YA(```@3```````````````[
M`````````````"P/````````````````````````````````````````````
M`````````````*```.X[``#G.P``*CT```0\```R/0```````/_____'/0``
M1T-#.B`H06QP:6YE(#8N-"XP*2`V+C0N,```+G-H<W1R=&%B`"YI;G1E<G``
M+F=N=2YH87-H`"YD>6YS>6T`+F1Y;G-T<@`N<F5L+F1Y;@`N<F5L+G!L=``N
M:6YI=``N<&QT+F=O=``N=&5X=``N9FEN:0`N<F]D871A`"YE:%]F<F%M95]H
M9'(`+F5H7V9R86UE`"YC=&]R<P`N9'1O<G,`+FIC<@`N9'EN86UI8P`N9&%T
M80`N8G-S`"YC;VUM96YT````````````````````````````````````````
M```````````````+`````0````(````T`0``-`$``!<```````````````$`
M````````$P```/;__V\"````3`$``$P!``"\`````P`````````$````!```
M`!T````+`````@````@"```(`@``(`8```0````!````!````!`````E````
M`P````(````H"```*`@``'$$``````````````$`````````+0````D````"
M````G`P``)P,``#``````P`````````$````"````#8````)````0@```%P-
M``!<#0``T`$```,````3````!`````@````_`````0````8````L#P``+`\`
M`!$```````````````$`````````.@````$````&````0`\``$`/``"P`P``
M```````````0````!````$4````!````!@```/`2``#P$@``&```````````
M````"`````@```!.`````0````8````($P``"!,``/@G``````````````$`
M````````5`````$````&`````#L````[```,```````````````!````````
M`%H````!`````@````P[```,.P``'C\`````````````!`````````!B````
M`0````(````L>@``+'H``-P```````````````0`````````<`````$````"
M````"'L```A[``!4#``````````````$`````````'H````!`````P```.2=
M``#DC0``"```````````````!`````````"!`````0````,```#LG0``[(T`
M``@```````````````0`````````B`````$````#````])T``/2-```$````
M```````````$`````````(T````&`````P```/B=``#XC0``T`````0`````
M````!`````@```!)`````0````,```#(G@``R(X``#@!``````````````0`
M```$````E@````$````#`````*````"0```D```````````````$````````
M`)P````(`````P```$"@```DD```-!``````````````(`````````"A````
M`0```#``````````))```!H```````````````$````!`````0````,`````
?`````````#Z0``"J```````````````!````````````
